@@ -54,6 +54,20 @@ namespace RESTAPI {
   }
 }
 
+/**
+ * Cancellable actions
+ */
+export interface ICancellableAction {
+  /**
+   * Type of cancellable action
+   */
+  type: string;
+  /**
+   * Cancellable function
+   */
+  cancel: () => void;
+}
+
 /**
  * Conda Environment Manager
  */
@@ -435,7 +449,7 @@ export class CondaPackage implements Conda.IPackageManager {
       return Promise.resolve([]);
     }
 
-    this._cancelTasks();
+    this._cancelTasks('default');
 
     try {
       const request: RequestInit = {
@@ -447,7 +461,7 @@ export class CondaPackage implements Conda.IPackageManager {
         URLExt.join('conda', 'environments', theEnvironment),
         request
       );
-      const idx = this._cancellableStack.push(cancel) - 1;
+      const idx = this._cancellableStack.push({ type: 'default', cancel }) - 1;
       const response = await promise;
       this._cancellableStack.splice(idx, 1);
       const data = (await response.json()) as {
@@ -630,7 +644,7 @@ export class CondaPackage implements Conda.IPackageManager {
       return Promise.resolve([]);
     }
 
-    this._cancelTasks();
+    this._cancelTasks('default');
 
     try {
       const request: RequestInit = {
@@ -641,7 +655,7 @@ export class CondaPackage implements Conda.IPackageManager {
           URLExt.objectToQueryString({ status: 'has_update' }),
         request
       );
-      const idx = this._cancellableStack.push(cancel) - 1;
+      const idx = this._cancellableStack.push({ type: 'default', cancel }) - 1;
       const response = await promise;
       this._cancellableStack.splice(idx, 1);
       const data = (await response.json()) as {
@@ -724,6 +738,36 @@ export class CondaPackage implements Conda.IPackageManager {
     }
   }
 
+  async getDependencies(
+    pkg: string,
+    cancellable = true
+  ): Promise<Conda.IPackageDeps> {
+    this._cancelTasks('getDependencies');
+
+    const request: RequestInit = {
+      method: 'GET'
+    };
+
+    const { promise, cancel } = Private.requestServer(
+      URLExt.join('conda', 'packages') +
+        URLExt.objectToQueryString({ dependencies: 1, query: pkg }),
+      request
+    );
+
+    let idx: number;
+    if (cancellable) {
+      idx =
+        this._cancellableStack.push({ type: 'getDependencies', cancel }) - 1;
+    }
+
+    const response = await promise;
+    if (idx) {
+      this._cancellableStack.splice(idx, 1);
+    }
+    const data = (await response.json()) as Conda.IPackageDeps;
+    return Promise.resolve(data);
+  }
+
   async refreshAvailablePackages(cancellable = true): Promise<void> {
     await this._getAvailablePackages(true, cancellable);
   }
@@ -747,7 +791,7 @@ export class CondaPackage implements Conda.IPackageManager {
     force = false,
     cancellable = true
   ): Promise<Array<Conda.IPackage>> {
-    this._cancelTasks();
+    this._cancelTasks('default');
 
     if (CondaPackage._availablePackages === null || force) {
       const request: RequestInit = {
@@ -760,7 +804,7 @@ export class CondaPackage implements Conda.IPackageManager {
       );
       let idx: number;
       if (cancellable) {
-        idx = this._cancellableStack.push(cancel) - 1;
+        idx = this._cancellableStack.push({ type: 'default', cancel }) - 1;
       }
       const response = await promise;
       if (idx) {
@@ -779,14 +823,16 @@ export class CondaPackage implements Conda.IPackageManager {
   /**
    * Cancel optional tasks
    */
-  private _cancelTasks(): void {
+  private _cancelTasks(type: string): void {
     if (this._cancellableStack.length > 0) {
       const tasks = this._cancellableStack.splice(
         0,
         this._cancellableStack.length
       );
-      tasks.forEach(task => {
-        task();
+      tasks.forEach(action => {
+        if (action.type === type) {
+          action.cancel();
+        }
       });
     }
   }
@@ -795,7 +841,7 @@ export class CondaPackage implements Conda.IPackageManager {
     CondaPackage,
     Conda.IPackageChange
   > = new Signal<this, Conda.IPackageChange>(this);
-  private _cancellableStack: Array<() => void> = [];
+  private _cancellableStack: Array<ICancellableAction> = [];
   private static _availablePackages: Array<Conda.IPackage> = null;
   private static _hasDescription = false;
 }
@@ -817,7 +863,7 @@ namespace Private {
    * @param {RequestInit} request : initialization parameters for the request
    * @returns {ICancellablePromise<Response>} : Cancellable response to the request
    */
-  export const requestServer = function(
+  export const requestServer = function (
     url: string,
     request: RequestInit
   ): ICancellablePromise<Response> {
